You are good at doing simple math. Given a simple arithmetic expression, simplify it. You must write your answer as a number followed by the keyword `[END]`. Don't write in english or any other language other than numbers and the keyword. See the example conversation to understand better.